@@ -1,6 +1,10 @@
 #!/usr/bin/env python
 # -*- coding:utf-8 -*-
 # @Author: Jialiang Shi
+try:
+    from urllib.parse import quote_plus
+except ImportError:
+    from urllib import quote_plus
 from gerrit.projects.project import GerritProject
 
 
@@ -39,6 +43,24 @@ class GerritProjects(object):
         result = self.gerrit.decode_response(response)
         return GerritProject.parse_list(result, gerrit=self.gerrit)
 
+    def regex(self, query):
+        """
+        Regex queries projects visible to the caller.
+        The query string must be provided by the query parameter.
+        The start and limit parameters can be used to skip/limit results.
+        query parameter
+         * Boundary matchers '^' and '$' are implicit.
+         * For example: the regex 'test.*' will match any projects that start with 'test' and regex
+           '.*test' will match any project that end with 'test'.
+         * The match is case sensitive.
+        :param query:
+        :return:
+        """
+        endpoint = "/projects/?r=%s" % query
+        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
+        result = self.gerrit.decode_response(response)
+        return GerritProject.parse_dict(result, gerrit=self.gerrit)
+
     def get(self, project_name):
         """
         Retrieves a project.
@@ -46,7 +68,7 @@ class GerritProjects(object):
         :param project_name: the name of the project
         :return:
         """
-        endpoint = "/projects/%s" % project_name
+        endpoint = "/projects/%s" % quote_plus(project_name)
         response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
         result = self.gerrit.decode_response(response)
         return GerritProject.parse(result, gerrit=self.gerrit)
@@ -72,7 +94,7 @@ class GerritProjects(object):
 
         :return:
         """
-        endpoint = "/projects/%s" % project_name
+        endpoint = "/projects/%s" % quote_plus(project_name)
         base_url = self.gerrit.get_endpoint_url(endpoint)
         response = self.gerrit.requester.put(
             base_url, json=input_, headers=self.gerrit.default_headers
@@ -87,5 +109,5 @@ class GerritProjects(object):
         :param project_name: project name
         :return:
         """
-        endpoint = "/projects/%s/delete-project~delete" % project_name
+        endpoint = "/projects/%s/delete-project~delete" % quote_plus(project_name)
         self.gerrit.requester.post(self.gerrit.get_endpoint_url(endpoint))
